@@ -8,3 +8,9 @@
 #undef HAVE_OPENSSL
 
 #undef ENABLE_PROFILER
+
+#undef ENABLE_NLS
+#undef HAVE_CATGETS
+#undef HAVE_GETTEXT
+#undef HAVE_LC_MESSAGES
+#undef HAVE_STPCPY
