@@ -61,9 +61,10 @@ static const int button_mappings [][3] = {
 };
 
 
+/* FIXME these marked strings below aren't actually ever translated */
 static const char * forgot_pw_buttons[] =
 {
-	_("I forgot my password"),
+	N_("I forgot my password"),
 	GNOME_STOCK_BUTTON_CANCEL,
 	GNOME_STOCK_BUTTON_OK,
 	NULL
@@ -71,7 +72,7 @@ static const char * forgot_pw_buttons[] =
 
 static const char * register_buttons[] =
 {
-	_("Register"),
+	N_("Register"),
 	GNOME_STOCK_BUTTON_CANCEL,
 	GNOME_STOCK_BUTTON_OK,
 	NULL
@@ -79,8 +80,8 @@ static const char * register_buttons[] =
 
 static const char * fail_buttons[] =
 {
-	_("Register"),
-	_("I forgot my password"),
+	N_("Register"),
+	N_("I forgot my password"),
 	GNOME_STOCK_BUTTON_OK,
 	NULL
 };
@@ -204,6 +205,26 @@ dialog_close_callback (GtkWidget *widget, gpointer callback_data)
 }
 
 /* Caption table callbacks */
+static void
+caption_table_tab_out_callback (GtkWidget *widget, gpointer callback_data)
+{
+	AmmoniteLoginDialog *password_dialog;
+	GtkWidget *button;
+
+	g_return_if_fail (callback_data != NULL);
+	g_return_if_fail (NAUTILUS_IS_PASSWORD_DIALOG (callback_data));
+
+	password_dialog = AMMONITE_LOGIN_DIALOG (callback_data);
+
+	button = g_list_nth_data (GNOME_DIALOG (password_dialog)->buttons, 
+				button_mappings[BUTTON_OK][password_dialog->details->button_mode]);
+	
+	g_assert (button != NULL);
+	g_assert (GTK_IS_BUTTON (button));
+
+	gtk_widget_grab_focus (button);
+}
+
 static void
 caption_table_activate_callback (GtkWidget *widget, gint entry, gpointer callback_data)
 {
@@ -214,13 +235,7 @@ caption_table_activate_callback (GtkWidget *widget, gint entry, gpointer callbac
 
 	password_dialog = AMMONITE_LOGIN_DIALOG (callback_data);
 
-	/* If the username entry was activated, simply advance the focus to the password entry */
-	if (entry == CAPTION_TABLE_USERNAME_ROW) {
-		nautilus_caption_table_entry_grab_focus (NAUTILUS_CAPTION_TABLE (password_dialog->details->table), 
-							 CAPTION_TABLE_PASSWORD_ROW);
-	}
-	/* If the password entry was activated, then simulate and OK button press to continue to hide process */
-	else if (entry == CAPTION_TABLE_PASSWORD_ROW) {
+	if (entry == CAPTION_TABLE_PASSWORD_ROW) {
 		GtkWidget *button;
 		
 		button = g_list_nth_data (GNOME_DIALOG (password_dialog)->buttons, 
@@ -310,6 +325,11 @@ ammonite_login_dialog_new	(EazelProxy_AuthnPromptKind prompt_kind,
 				   GTK_SIGNAL_FUNC (caption_table_activate_callback),
 				   (gpointer) password_dialog);
 
+		gtk_signal_connect (GTK_OBJECT (password_dialog->details->table),
+				   "tab-out",
+				   GTK_SIGNAL_FUNC (caption_table_tab_out_callback),
+				   (gpointer) password_dialog);
+	
 		nautilus_caption_table_set_row_info (NAUTILUS_CAPTION_TABLE (password_dialog->details->table),
 						     CAPTION_TABLE_USERNAME_ROW,
 						     "User Name:",
@@ -340,7 +360,7 @@ ammonite_login_dialog_new	(EazelProxy_AuthnPromptKind prompt_kind,
 		ammonite_login_dialog_set_password (password_dialog, password);
 		ammonite_login_dialog_set_readonly_username (password_dialog, readonly_username);
 	} else {
-		static const char *fail_message = 
+		const char *fail_message = 
 			_(
 			  "If you do not already have an Eazel Service account and "
 			  "would like one, please click on the "
