@@ -1,4 +1,4 @@
-/* $Id: libammonite-gtk.c,v 1.8 2000/10/30 22:22:35 robey Exp $
+/* $Id: libammonite-gtk.c,v 1.12 2001/01/17 03:59:55 mfleming Exp $
  * 
  * Copyright (C) 2000 Eazel, Inc
  *
@@ -35,9 +35,6 @@
 /* FIXME this is not the real URI */
 #define EAZEL_ACCOUNT_FORGOTPW_URI "eazel-services://anonymous/account/login/lost_pwd_form"
 
-#define KEY_GCONF_TRILOBITE_DEFAULT_USER "/apps/eazel-trilobite/default-services-user"
-
-
 #ifdef DEBUG
 #define DEBUG_MSG(x) my_debug_printf x
 #include <stdio.h>
@@ -89,6 +86,10 @@ authn_cb_succeeded (const EazelProxy_User *user, gpointer state, CORBA_Environme
 
 	p_state = (PromptLoginState *)state;
 
+	if (user->is_default) {
+		ammonite_save_previous_default_username (user->user_name);
+	}
+
 	if (p_state->callback) {
 		p_state->callback (p_state->user_data, user, NULL);
 	}
@@ -192,64 +193,12 @@ prompter_cb_prompt_authenticate (
 	return ret;
 }
 
-static gboolean
-evil_init_gconf (void)
-{
-	GError *error = NULL;
-	
-	if (!gconf_is_initialized ()) {
-		char		  *argv[] = { "libammonite", NULL };
-		
-		if (!gconf_init (1, argv, &error)) {
-			g_assert (error != NULL);
-			
-			g_warning ("GConf init failed:\n  %s", error->message);
-			
-			g_error_free (error);
-			
-			error = NULL;
-			
-			return FALSE;
-		}
-	}
-	return TRUE;
-}
-
-static char *
-get_default_username (void)
-{
-	GConfValue *value_gconf;
-	GConfEngine *engine_gconf;
-	GError * err_gconf = NULL;
-	char * ret;
-
-	if ( ! evil_init_gconf () ) {
-		return NULL;
-	}
-
-	engine_gconf = gconf_engine_get_default();
-
-	value_gconf = gconf_engine_get (engine_gconf, KEY_GCONF_TRILOBITE_DEFAULT_USER, &err_gconf);
-
-	if (NULL == value_gconf || NULL != err_gconf 
-	    || GCONF_VALUE_STRING != value_gconf->type) {
-		ret = NULL;
-	} else {
-		ret = g_strdup (gconf_value_get_string (value_gconf));
-		gconf_value_free (value_gconf);
-		value_gconf = NULL;
-	}
-
-	gconf_engine_unref (engine_gconf);
-
-	return ret;
-}
-
 gboolean
 ammonite_do_prompt_login_async (
 	const char *username, 
 	const char *services_redirect_uri, 
 	const char *services_login_path,
+	gboolean is_default,
 	gpointer user_data,
 	AmmonitePromptLoginCb callback
 ) {
@@ -295,10 +244,10 @@ ammonite_do_prompt_login_async (
 	authinfo->services_login_path = CORBA_string_dup (services_login_path ? services_login_path : "");
 
 	/* If a username wasn't supplied, see if we can get what the user last used */
-	if (NULL == username) {
+	if (NULL == username && is_default) {
 		char * default_username;
 
-		default_username = get_default_username();
+		default_username = ammonite_get_previous_default_username();
 		if (NULL == default_username) {
 			authinfo->username = CORBA_string_dup ("");
 		} else {
@@ -306,6 +255,8 @@ ammonite_do_prompt_login_async (
 			g_free (default_username);
 			p_state->prompt_user_name_can_be_changed = TRUE;
 		}
+	} else if (NULL == username) {
+		authinfo->username = CORBA_string_dup ("");
 	} else {
 		/* For some cases (such as prompting after an eazel-service://user/path URL)
 		 * we can't allow the user to change the username in the prompt dialog
@@ -316,7 +267,7 @@ ammonite_do_prompt_login_async (
 
 	DEBUG_MSG (("%lu: Calling prompt_authenticate\n", (unsigned long) getpid()));
 
-	EazelProxy_UserControl_prompt_authenticate_user (ammonite_get_user_control(), authinfo, TRUE, userprompter, authn_callback, &ev);
+	EazelProxy_UserControl_prompt_authenticate_user (ammonite_get_user_control(), authinfo, is_default, userprompter, authn_callback, &ev);
 
 	DEBUG_MSG (("%lu: Back from prompt_authenticate\n", (unsigned long) getpid()));
 
@@ -357,6 +308,7 @@ ammonite_do_prompt_login (
 	const char *username, 
 	const char *services_redirect_uri, 
 	const char *services_login_path,
+	gboolean is_default,
 	/*OUT*/ CORBA_long *p_fail_code
 ) {
 
@@ -374,6 +326,7 @@ ammonite_do_prompt_login (
 		username, 
 		services_redirect_uri, 
 		services_login_path,
+		is_default,
 		(gpointer)&state,
 		prompt_login_sync_cb
 	);
@@ -398,7 +351,7 @@ ammonite_do_prompt_login (
 
 		DEBUG_MSG (("%lu: Response iteration complete, success=%s\n", (unsigned long) getpid(), state.fail_info ? "FALSE" : "TRUE"));
 
-		if (state.fail_info ) {
+		if (state.fail_info) {
 			if (p_fail_code) { 
 				*p_fail_code = state.fail_info->code;
 			}
@@ -411,12 +364,8 @@ ammonite_do_prompt_login (
 		}
 	}
 
-	if ( ! user
-		  && ( EAZELPROXY_AUTHN_FAIL_NETWORK == fail_code
-		  		|| EAZELPROXY_AUTHN_FAIL_SERVER == fail_code
-		  )
-	) {
-		ammonite_do_network_error_dialog();
+	if (user == NULL) {
+		ammonite_do_authn_fail_dialog (fail_code);
 	}
 
 error:
@@ -557,12 +506,36 @@ ammonite_do_authn_error_dialog ()
 
 void
 ammonite_do_network_error_dialog ()
+{
+	ammonite_do_authn_fail_dialog (EAZELPROXY_AUTHN_FAIL_NETWORK);
+}
+
+void
+ammonite_do_authn_fail_dialog (CORBA_long fail_code)
 {
 	GtkWidget *dialog;
+	const char *message;
 
-	DEBUG_MSG (("Opening Network Error Dialog\n"));
+	DEBUG_MSG (("Opening Authn Fail Dialog\n"));
 
-	dialog = gnome_error_dialog ("I'm sorry, network problems are preventing you from connecting to Eazel Services.");
+	/* It should be noted that these strings are currently duplicatedin
+	 * in the nautilus-summary-view code
+	 */
+	if (fail_code == EAZELPROXY_AUTHN_FAIL_NETWORK
+	    || fail_code == EAZELPROXY_AUTHN_FAIL_SERVER) {
+		message = _("I'm sorry, network problems are preventing you from connecting to Eazel Services.");
+	} else if (fail_code == EAZELPROXY_AUTHN_FAIL_USER_NOT_ACTIVATED) {
+		message = _("Your Eazel Services account has not yet been activated.  "
+			    "You can't log in to Eazel Services until you activate your account.\n\n"
+			    "Please check your email messages for activation instructions.");
+	} else if (fail_code == EAZELPROXY_AUTHN_FAIL_USER_DISABLED) {
+		message = _("Your Eazel Services has been temporarily disabled.\n"
+			    "Please try again in a few minutes or contact Eazel support if this continues.");
+	} else {
+		return;
+	}
+	
+	dialog = gnome_error_dialog (message);
 
 	gnome_dialog_run_and_close (GNOME_DIALOG (dialog));
 
@@ -573,3 +546,4 @@ ammonite_do_network_error_dialog ()
 }
 
 
+
