@@ -1,4 +1,4 @@
-/* $Id: eazelproxy-change-password.c,v 1.16 2000/10/30 22:22:35 robey Exp $
+/* $Id: eazelproxy-change-password.c,v 1.19 2001/01/19 00:08:08 robey Exp $
  * 
  * Copyright (C) 2000 Eazel, Inc
  *
@@ -216,22 +216,25 @@ set_user_password_success (SetUserPasswordInfo *state_info)
 }
 
 
-/* <?xml version="1.0" encoding="utf-8" ?>
- * <response code="%d">[localized text]</response>
+/* [18jan01 robey] triggerfish sends messages that look like this:
+ * 	<http-equiv>
+ *	    <status>302</status>
+ *	    <message></message>
+ *	    <location>/account/password/form?err=502</location>
+ *	</http-equiv>
+ * the only part we're interested in here is the 'err=XXX' piece:
+ * that's the code that tells us if it succeeded or failed, or
+ * what.  generally, 501-506 are errors.
  *
- * The codes should be as follows:
+ * for a success message, we get the same, except the <location>
+ * line looks like this instead:
+ *	    <location>/services</location>
  *
- * code    significance            localized message
- * 0       OK--pw changed          <none required>
- * 1       bad password            <explain why the password is bad--this will be displayed directly>
- * 2       new pw's do not match   <none required>  (I'll never get this error since I'll check the PW's client-side)
- * 3       Old password incorrect  <none required>
+ * so basically, i'm going to look for "err=".  if it's there, we
+ * have an error code (at least one: sometimes the error code is
+ * something like "err=503+506" but the first one is usually enough
+ * info).  if it's not there, return code 0 because we succeeded!
  */
-
-#define CHPW_RESPONSE_OK	0
-#define CHPW_RESPONSE_BAD_PW	1
-#define CHPW_RESPONSE_BAD_OLDPWD 3
-
 static void
 set_user_password_http_read_callback /*HttpReadCallbackFn*/ (
 	gpointer user_data, 
@@ -244,10 +247,9 @@ set_user_password_http_read_callback /*HttpReadCallbackFn*/ (
 	SetUserPasswordInfo *state_info;
 	HttpStatusLine parsed_status_line;
 	xmlDocPtr body_doc = NULL;
-	xmlChar * code_property = NULL;
-	long code;
-	char * text;
-	xmlChar * code_property_out;
+	long code = 0;
+	char *text = NULL;
+        char *ptr = NULL;
 	char *body_copy = NULL;
 	char *body_copy_ptr = NULL;
 
@@ -279,8 +281,6 @@ set_user_password_http_read_callback /*HttpReadCallbackFn*/ (
 		goto done;
 	}
 
-#define EVIL_PR2_HACK
-
 	/* evil, EVIL bug in libxml!
 	 * even if you pass in a length to the xml parser, it requires the buffer to be null-terminated.
 	 * so we need to copy the buffer and add a null terminator. :(
@@ -297,7 +297,7 @@ set_user_password_http_read_callback /*HttpReadCallbackFn*/ (
 
 	if ( NULL == body_doc ) {
 		log ("Change PW: XML response was bad");
-		log ("XML was: '%s'", body_copy_ptr);
+		log ("XML was: (%d) '%s'", body_size - (body_copy_ptr - body_copy), body_copy_ptr);
 		set_user_password_failed_force_logout (
 						       state_info,
 						       EAZELPROXY_AUTHN_FAIL_SERVER,
@@ -306,80 +306,26 @@ set_user_password_http_read_callback /*HttpReadCallbackFn*/ (
 		goto done;
 	}
 
-#ifdef EVIL_PR2_HACK
-	/* so... what ammonite is expecting is nothing like what triggerfish is sending.
-	 * parse what triggerfish sends and translate to a code.
-	 */
-
+        /* for now, text is never set: use the force, luke. */
+        text = "";
 	if (body_doc != NULL) {
-		/* ALSO: libxml is completely unable to parse this http-equiv block and i don't have time to
-		 * mess with it.  so, i give up, we'll search for substrings.
-		 */
-		if (strstr (body_copy_ptr, "/services") != NULL) {
-			code = CHPW_RESPONSE_OK;
-			text = "You are the luckiest person alive.";
-			log ("Change PW OK");
-		} else {
-			code = CHPW_RESPONSE_BAD_PW;
-			text = "The new password is wrong, for some reason.";
-			log ("Change PW BAD");
-		}
-	}
-	code_property_out = code_property_out;
-#else
-
-	if ( 	NULL == body_doc->root ||
-		0 != g_strcasecmp ( body_doc->root->name, "response" )
-		|| NULL == ( code_property = xmlGetProp (body_doc->root, "code") )
-	) {
-		log ("Change PW: XML response was bad (no response/code key?)");
-		log ("XML was: '%s'", body_copy_ptr);
-		set_user_password_failed_force_logout (
-			state_info,
-			EAZELPROXY_AUTHN_FAIL_SERVER,
-			NULL
-		);
-		goto done;
-	}
-
-	/*
-	 * You cannot simply access the content via ->content
-	 *  if the content is buffered (also to access from
-	 *   the xmlBufferPtr-stuff)!
-	 */
-	#ifdef XML_USE_BUFFER_CONTENT
-	text = xmlNodeGetContent(body_doc->root);
-	#else
-	text = body_doc->root->content;
-	#endif
-	code = strtol (code_property, (char **)&code_property_out, 10);
-
-	if (code_property == code_property_out) {
-		log ("Change PW: XML response was bad (couldn't decode code)");
-		log ("XML was: '%s'", body_copy_ptr);
-		set_user_password_failed_force_logout (
-			state_info,
-			EAZELPROXY_AUTHN_FAIL_SERVER,
-			NULL
-		);
-		goto done;
-	} 
-#endif
-
-	if ( CHPW_RESPONSE_OK == code ) {
-		log ("Change PW: Success!");
-		set_user_password_success (state_info);
-	} else {
-		log ("Change PW: Got fail code %d text '%s'", code, text);
-		set_user_password_failed (
-			state_info,
-			EAZELPROXY_PASSWORD_FAIL_OFFSET + code,
-			text
-		);
-	}
-
-	if (code_property) {
-		free (code_property);	
+                ptr = strstr (body_copy_ptr, "err=");
+                if (ptr != NULL) {
+                        /* error */
+                        ptr += 4;
+                        code = atoi (ptr);
+                        log ("Change PW failed: error %d", code);
+                        set_user_password_failed (
+                                                  state_info,
+                                                  code,
+                                                  text
+                                                  );
+                } else {
+                        /* success! */
+                        code = 0;
+                        log ("Change PW success");
+                        set_user_password_success (state_info);
+                }
 	}
 
 done:
@@ -417,7 +363,7 @@ set_user_password_http_callback (gpointer user_data, Socket *sock, gboolean succ
 static void
 set_user_password_submit_request (SetUserPasswordInfo *state_info)
 {
-	HTTPRequest *request;
+	HTTPRequestLine *request;
 	char *post_data;
 	GList *header_list = NULL;
 	char *old_password_escaped = NULL, *new_password_escaped = NULL;
