@@ -1,4 +1,4 @@
-/* $Id: http-connection.c,v 1.20 2000/10/30 21:08:40 mfleming Exp $
+/* $Id: http-connection.c,v 1.23 2001/01/16 21:30:08 mfleming Exp $
  * 
  * Copyright (C) 2000 Eazel, Inc
  *
@@ -39,12 +39,12 @@
 #endif
 
 /*
- * HTTPConnection types
+ * HTTPRequest types
  */ 
 
-struct HTTPConnection {
+struct HTTPRequest {
 	guint32		magic;
-	HTTPRequest	*request;
+	HTTPRequestLine	*request;
 	GList		*header_list;
 	Socket		*server_socket;
 	gboolean	proxy_connect;	/* TRUE if we're connecting to a proxy */
@@ -52,16 +52,22 @@ struct HTTPConnection {
 	gpointer	user_data;
 };
 
+#define HTTP_REQUEST_MAGIC 0x17C3220C
+#define IS_HTTP_REQUEST(x) ((x) && HTTP_REQUEST_MAGIC == (x)->magic)
+
 typedef struct {
 	char *		submit_body;
 	size_t		cb_submit_body;  /* cb_ means "count byte" */
 	HttpCallbackFn	callback;
 	gpointer	user_data;
-} HTTPConnectSubmit;
-
-#define HTTP_CONNECTION_MAGIC 0x17C3220C
-#define IS_HTTP_CONNECTION(conn) ((conn) && HTTP_CONNECTION_MAGIC == (conn)->magic)
+} HTTPRequestSubmit;
 
+#ifdef HTTP_PERSISTANT_UPSTREAM
+typedef struct {
+	Socket *	connection_socket;
+	GList *		request_list;
+} HTTPConnection;
+#endif
 
 /*
  * HttpGetHeaderState types
@@ -101,8 +107,8 @@ typedef struct {
 
 static void http_connection_sock_connect (Socket *sock, int success);
 static void http_connection_connect_sock_eof (Socket *sock);
-static void http_connection_free (HTTPConnection *http_connection);
-static void http_connection_finish (HTTPConnection *http_connection, gboolean success);
+static void http_connection_free (HTTPRequest *http_connection);
+static void http_connection_finish (HTTPRequest *http_connection, gboolean success);
 
 static void /* HttpCallbackFn */ connect_submit_http_callback (gpointer user_data, Socket *sock, gboolean success);
 
@@ -348,9 +354,9 @@ http_parse_authn_header ( /*INOUT*/ char **p_header, /*OUT*/ char **p_key, /*OUT
  */
 
 
-HTTPConnection *
+HTTPRequest *
 http_connection_connect (
-	const HTTPRequest *request,
+	const HTTPRequestLine *request,
 	GList *		header_list,
 	gpointer 	user_data, 
 	HttpCallbackFn 	callback
@@ -358,16 +364,16 @@ http_connection_connect (
 	,FILE * fm_mirror_arg, FILE * to_mirror_arg
 #endif /* DEBUG */ 
 ) {
-	HTTPConnection *http_connection;
+	HTTPRequest *http_connection;
 	Socket *server_socket;
 	gboolean success;
 	int err;
 
 	g_return_val_if_fail ( NULL != request, FALSE);
 
-	http_connection = g_new0(HTTPConnection,1);
+	http_connection = g_new0(HTTPRequest,1);
 
-	http_connection->magic = HTTP_CONNECTION_MAGIC;
+	http_connection->magic = HTTP_REQUEST_MAGIC;
 	http_connection->request = request_copy (request);
 
 	http_connection->header_list = header_list;
@@ -461,22 +467,22 @@ http_connection_connect (
  * Note, if FALSE is returned, the callback is never called!
  */
 
-HTTPConnection *
+HTTPRequest *
 http_connection_connect_submit (
-	const HTTPRequest *request,
+	const HTTPRequestLine *request,
 	GList *		header_list,
 	char *		submit_body,
 	size_t 		cb_submit_body,	/*cb_ means "count bytes' */
 	gpointer 	user_data, 
 	HttpCallbackFn 	callback
 ) {
-	HTTPConnectSubmit * submit_state;
-	HTTPConnection *ret;
+	HTTPRequestSubmit * submit_state;
+	HTTPRequest *ret;
 
 	g_return_val_if_fail (NULL != request, FALSE);
 	g_return_val_if_fail (NULL != callback, FALSE);
 
-	submit_state = g_new0 (HTTPConnectSubmit, 1);
+	submit_state = g_new0 (HTTPRequestSubmit, 1);
 
 	submit_state->submit_body 	= submit_body; 
 	submit_state->cb_submit_body 	= cb_submit_body; 
@@ -525,9 +531,9 @@ http_connection_connect_submit (
  */
  
 void
-http_connection_abort (HTTPConnection *connection)
+http_connection_abort (HTTPRequest *connection)
 {
-	g_return_if_fail (IS_HTTP_CONNECTION (connection));
+	g_return_if_fail (IS_HTTP_REQUEST (connection));
 
 	socket_set_read_fn (connection->server_socket, NULL);
 	socket_set_eof_fn (connection->server_socket, NULL);
@@ -576,7 +582,7 @@ http_connection_sock_connect (Socket *sock, int success)
 {
 	char *request_line;
 	int result;
-	HTTPConnection *http_connection;
+	HTTPRequest *http_connection;
 	GList *current_position;
 
 
@@ -585,7 +591,7 @@ http_connection_sock_connect (Socket *sock, int success)
 	http_connection = socket_get_data (sock);
 
 	g_assert (NULL != http_connection);
-	g_assert (IS_HTTP_CONNECTION (http_connection));
+	g_assert (IS_HTTP_REQUEST (http_connection));
 
 	if (!success) {
 		http_connection_finish (http_connection, FALSE);
@@ -593,7 +599,7 @@ http_connection_sock_connect (Socket *sock, int success)
 	}
 
 	if (http_connection->proxy_connect ){
-		HTTPRequest *req = http_connection->request;
+		HTTPRequestLine *req = http_connection->request;
 		
 		request_line=g_strdup_printf ("%s %s://%s:%d%s HTTP/%s\r\n",
 			req->method,
@@ -604,7 +610,7 @@ http_connection_sock_connect (Socket *sock, int success)
 			req->version
 		);
 	} else {
-		HTTPRequest *req = http_connection->request;
+		HTTPRequestLine *req = http_connection->request;
 		
 		request_line=g_strdup_printf ("%s %s HTTP/%s\r\n",
 			req->method,
@@ -613,6 +619,11 @@ http_connection_sock_connect (Socket *sock, int success)
 		);
 	}
 
+	/* Cork until we're finished writing headers.  This means we're likely
+	 * to consolidate writes into fewer packets
+	 */
+
+	socket_cork (sock);
 
 	result = socket_write (sock, request_line, strlen (request_line));
 	g_free (request_line);
@@ -645,35 +656,36 @@ http_connection_sock_connect (Socket *sock, int success)
 	}
 	result = socket_write (sock, "\r\n", 2);
 	
+	socket_uncork (sock);
+
 	if ( 1 != result ) {
 		http_connection_finish (http_connection, FALSE);
 		return;
 	}
 
 	http_connection_finish (http_connection, TRUE);
-
 }
 
 static void
 http_connection_connect_sock_eof (Socket *sock)
 {
-	HTTPConnection *http_connection;
+	HTTPRequest *http_connection;
 
 	g_assert (IS_SOCKET (sock));
 	
 	http_connection = socket_get_data (sock);
 
 	g_assert (NULL != http_connection);
-	g_assert (IS_HTTP_CONNECTION (http_connection));
+	g_assert (IS_HTTP_REQUEST (http_connection));
 
 	g_return_if_fail ( NULL != http_connection );
-	g_return_if_fail ( IS_HTTP_CONNECTION (http_connection) );
+	g_return_if_fail ( IS_HTTP_REQUEST (http_connection) );
 
 	http_connection_finish (http_connection, FALSE);
 }
 
 static void
-http_connection_free (HTTPConnection *http_connection)
+http_connection_free (HTTPRequest *http_connection)
 {
 	GList * current_node;
 	
@@ -693,13 +705,13 @@ http_connection_free (HTTPConnection *http_connection)
 }
 
 static void
-http_connection_finish (HTTPConnection *http_connection, gboolean success)
+http_connection_finish (HTTPRequest *http_connection, gboolean success)
 {
 	HttpCallbackFn callback_fn;
 	gpointer user_data;
 	Socket * socket;
 
-	g_assert (IS_HTTP_CONNECTION (http_connection));
+	g_assert (IS_HTTP_REQUEST (http_connection));
 
 	callback_fn = http_connection->callback;
 	user_data = http_connection->user_data;
@@ -724,10 +736,10 @@ http_connection_finish (HTTPConnection *http_connection, gboolean success)
 static void /* HttpCallbackFn */
 connect_submit_http_callback (gpointer user_data, Socket *sock, gboolean success)
 {
-	HTTPConnectSubmit *submit_state;
+	HTTPRequestSubmit *submit_state;
 	int result;
 
-	submit_state = (HTTPConnectSubmit *)user_data;
+	submit_state = (HTTPRequestSubmit *)user_data;
 
 	if (!success) {
 		submit_state->callback (submit_state->user_data, sock, FALSE);
@@ -763,12 +775,11 @@ http_read_state_info_free (HttpReadStateInfo *state_info)
 		g_free ((char *)list_node->data);
 	}
 
-	for (	list_node = g_list_first (state_info->body_pieces_list) ;
-		NULL != list_node ;
-		list_node = g_list_next (list_node)
-	) {
-		g_free ((char *)list_node->data);
-	}
+	g_list_free (state_info->header_list);
+
+	piece_response_free (state_info->body_pieces_list);
+
+	g_free (state_info);
 }
 
 static void /* SocketReadFn */
