@@ -1,5 +1,5 @@
 
-/* $Id: impl-eazelproxy.c,v 1.60 2000/11/01 23:15:53 mfleming Exp $
+/* $Id: impl-eazelproxy.c,v 1.66 2001/01/22 08:53:32 yakk Exp $
  * 
  * Copyright (C) 2000 Eazel, Inc
  *
@@ -54,6 +54,7 @@
 #define AUTHN_PROMPT_RETRIES 2		/* three prompts total */
 
 #define KEY_GCONF_NAUTILUS_USER_LEVEL "/apps/nautilus/user_level"
+#define KEY_GCONF_EAZEL_MACHINE_NAME "/apps/eazel-trilobite/machine_name"
 
 #define KEY_GCONF_DEFAULT_SERVICES_URI "/apps/eazel-trilobite/services-host"
 #define KEY_GCONF_DEFAULT_LOGIN_PATH "/apps/eazel-trilobite/default-services-login-path"
@@ -85,6 +86,11 @@ static pid_t gl_util_pid = 0;
 gchar * gl_user_level;
 gboolean gl_user_level_have 		= FALSE;
 
+/* The current Eazel Services Machine Name setting */
+/* exported for authenticate_add_default_headers:eazelproxy-authn.c */
+gchar * gl_machine_name;
+gboolean gl_machine_name_have 		= FALSE;
+
 /* Default ammonite settings */
 static gchar * gl_default_services_uri		= NULL;
 static gchar * gl_default_login_path		= NULL;
@@ -128,31 +134,58 @@ watch_gconf_user_level_cb (
 }
 
 
+static void /* UtilGConfCb */
+watch_gconf_machine_name_cb (
+	const UtilGConfWatchVariable *watched, 
+	const GConfValue *new_value
+) {
+	if (NULL == new_value) {
+		gl_machine_name_have = FALSE;
+		log ("machine name unset", gconf_value_get_string (new_value));
+	} else if (GCONF_VALUE_STRING == new_value->type ) {
+		gl_machine_name_have = TRUE;
+		log ("machine name changed to '%s'", gconf_value_get_string (new_value));
+	}
+}
+
+
 static void /* UtilGConfCb */
 watch_gconf_services_uri_cb (
 	const UtilGConfWatchVariable *watched, 
 	const GConfValue *new_value
 ) {
 	/* GConf variable should be in host:port format--convert to url */
-	char *old;
 
-	old = gl_default_services_uri;
+	g_free (gl_default_services_uri);
+	gl_default_services_uri = NULL;
 
-	/* If we're in SSL mode, default to port 443 */
-	if (config.use_ssl && NULL == strchr (gl_default_services_uri, ':' )) {
-		gl_default_services_uri = g_strdup_printf("http://%s:443/", gl_default_services_uri);
-	} else {
-		gl_default_services_uri = g_strdup_printf("http://%s/", gl_default_services_uri);
+	if (NULL == new_value) {
+		log ("gconf services-host unset (hardcoded value will be used)");
+	} else if (GCONF_VALUE_STRING == new_value->type) {
+		/* If we're in SSL mode, default to port 443 */
+		if (config.use_ssl && NULL == strchr (gconf_value_get_string (new_value), ':' )) {
+			gl_default_services_uri = g_strdup_printf ("http://%s:443/", gconf_value_get_string (new_value));
+		} else {
+			gl_default_services_uri = g_strdup_printf ("http://%s/", gconf_value_get_string (new_value));
+		}
+		
+		if ( ! util_validate_url (gl_default_services_uri)) {
+			log ("Invalid 'services-host' GConf setting (must be host:(port)?)");
+
+			g_free (gl_default_services_uri);
+			gl_default_services_uri = NULL;
+		} else {
+			log ("default services URI set to %s", gl_default_services_uri);
+		}
 	}
-	g_free (old);
-	
-	if ( ! util_validate_url (gl_default_services_uri)) {
-		log ("Invalid 'services-host' GConf sessing setting (must be host:(port)?)");
 
-		g_free (gl_default_services_uri);
-		gl_default_services_uri = NULL;
-	} else {
-		log ("default services URI set to %s", gl_default_services_uri);
+	/* Fall back to hard-coded value */
+	if (NULL == gl_default_services_uri) {
+		if (config.use_ssl) {
+			gl_default_services_uri = g_strdup (DEFAULT_SERVICES_SSL_URI);
+		} else {
+			gl_default_services_uri = g_strdup (DEFAULT_SERVICES_URI);
+		}
 	}
 }
 
@@ -162,6 +195,7 @@ get_defaults_from_gconf ()
 	static const UtilGConfWatchVariable to_watch[] = {
 		/* Nautilus user level -- so it can be appended to the proxied request headers */
 		{KEY_GCONF_NAUTILUS_USER_LEVEL, GCONF_VALUE_STRING, {(gchar **)&gl_user_level}, watch_gconf_user_level_cb},
+		{KEY_GCONF_EAZEL_MACHINE_NAME, GCONF_VALUE_STRING, {(gchar **)&gl_machine_name}, watch_gconf_machine_name_cb},
 		/* Default services URI--where incoming HTTP requests should be redirected  */
 		{KEY_GCONF_DEFAULT_SERVICES_URI, GCONF_VALUE_STRING, {(gchar **)&gl_default_services_uri}, watch_gconf_services_uri_cb},
 		/* Default login path -- path below services URI where authn requests should be pointed */
@@ -393,6 +427,8 @@ EazelProxy_UserList_make_from_glist (GList *list)
 
 	ret = EazelProxy_UserList__alloc();
 
+	CORBA_sequence_set_release (ret, TRUE);
+
 	if ( NULL == list ) {
 		ret->_length = 0;
 		ret->_buffer = NULL;
@@ -454,7 +490,7 @@ user_authenticate_cb (
 );
 
 
-static gpointer /* ProxyRequestCb */ user_proxy_request_cb (gpointer user_data, unsigned short port, HTTPRequest *request, GList **p_header_list);
+static gpointer /* ProxyRequestCb */ user_proxy_request_cb (gpointer user_data, unsigned short port, HTTPRequestLine *request, GList **p_header_list);
 
 static void /* ProxyResponseCb */ user_proxy_response_cb (gpointer user_data, gpointer connection_user_data, unsigned short port, char ** p_response_line, GList **p_header_list);
 
@@ -647,7 +683,7 @@ user_activate (User *user)
 	g_assert (0 == user->user.proxy_port);
 	g_assert (EazelProxy_AUTHENTICATING == user->user.login_state);
 
-	user->user.proxy_port = proxy_listen (0, user, &callbacks, user->user.services_redirect_uri);
+	user->user.proxy_port = proxy_listen ("127.0.0.1", 0, user, &callbacks, user->user.services_redirect_uri);
 
 	if ( 0 != user->user.proxy_port ) {
 
@@ -893,7 +929,12 @@ user_authenticate_cb (
 	} else {
 
 		user->p_digest = p_digest;
-		user->user.login_http_response = authn_post_response;
+		/* No one's using login_http_response and it's to too heavy
+		 * to carry around with every user and be returned on
+		 * all these CORBA calls.
+		 */
+		/* user->user.login_http_response = authn_post_response; */
+		g_free (authn_post_response);
 
 		if( ! user_activate (user) ) {
 			user->user.login_state = EazelProxy_UNAUTHENTICATED;
@@ -926,7 +967,7 @@ user_glist_string_cmp (gconstpointer a, gconstpointer b)
 #endif
 
 static gpointer /* ProxyRequestCb */
-user_proxy_request_cb (gpointer user_data, unsigned short port, HTTPRequest *request, GList **p_header_list)
+user_proxy_request_cb (gpointer user_data, unsigned short port, HTTPRequestLine *request, GList **p_header_list)
 {
 	User *user;
 	char *digest_header;
@@ -977,7 +1018,7 @@ user_proxy_request_cb (gpointer user_data, unsigned short port, HTTPRequest *req
 	if (destination_node) {
 		char *new_header;
 		char *dest_url;
-		HTTPRequest *dest_request;
+		HTTPRequestLine *dest_request;
 
 		dest_url = (char *)(destination_node->data) + strlen ("Destination: ");
 
@@ -1012,6 +1053,10 @@ user_proxy_request_cb (gpointer user_data, unsigned short port, HTTPRequest *req
 		*p_header_list = g_list_append (*p_header_list, g_strdup_printf ("X-Eazel-User-Level: %s", gl_user_level));
 	}
 
+	if (gl_machine_name_have) {
+		*p_header_list = g_list_append (*p_header_list, g_strdup_printf ("X-Eazel-Machine-Name: %s", gl_machine_name));
+	}
+
 	return GUINT_TO_POINTER (user->authn_count);
 }
 
@@ -1513,7 +1558,7 @@ impl_EazelProxy_UserControl_get_active_users  (PortableServer_Servant servant, C
 static void
 my_authenticate_user (User *user, const char *password, AuthenticateCallbackFn callback_fn)
 {
-	HTTPRequest *request;
+	HTTPRequestLine *request;
 
 	/* The "anonymous" user is a special case.  When the username is
 	 * "anonymous", the normal login process is skipped and authentication
