@@ -1,4 +1,4 @@
-/* $Id: request.c,v 1.39 2000/11/01 23:15:53 mfleming Exp $
+/* $Id: request.c,v 1.42 2001/01/16 21:30:08 mfleming Exp $
  *
  * Handles incoming request callbacks, buffers headers, and passes
  * the request on to the upstream server.
@@ -90,9 +90,9 @@ static int connection_id_counter = 0;
 typedef struct {
 	guint32 	magic;
 	int 		id;
-        HTTPRequest *	request;
+        HTTPRequestLine *	request;
 
-	HTTPConnection * http_connection;
+	HTTPRequest *	http_request;
         Socket *	server;
         gboolean	upstream_proxy;	/* TRUE if the http request has to be phrased for an upstream proxy */
 	HttpGetHeaderState *p_header_state_request;
@@ -450,6 +450,8 @@ proxy_response_headers_write (Socket *socket_client, char *response_line, GList
 {
 	int err;
 	GList *current_position;
+
+	socket_cork (socket_client);
 	
 	err = socket_write (socket_client, response_line, strlen (response_line));
 	err = socket_write (socket_client, "\r\n", 2);
@@ -462,6 +464,9 @@ proxy_response_headers_write (Socket *socket_client, char *response_line, GList
 		err = socket_write (socket_client, "\r\n", 2);
 	}
 	err = socket_write (socket_client, "\r\n", 2);
+
+	socket_uncork (socket_client);
+
 }
 
 
@@ -554,8 +559,8 @@ proxy_abort_connect(Socket *sock)
 
 	log ("%d client aborted", conn->id);
 
-	if (NULL != conn->http_connection) {
-		http_connection_abort (conn->http_connection);
+	if (NULL != conn->http_request) {
+		http_connection_abort (conn->http_request);
 	}
 
 	/* This should only be created by CONNECT method requests */
@@ -609,7 +614,7 @@ proxy_method_connect_callback(Socket *server_sock, int success)
 
 /**
  * proxy_http_connect_callback
- * http_connection callback after connection triggered in
+ * http_request callback after connection triggered in
  * proxy_do_connect
  */
 static void /* HttpCallbackFn */
@@ -623,7 +628,7 @@ proxy_http_connect_callback (gpointer user_data, Socket *server_sock, gboolean s
 	conn = (Connection *) socket_get_data (client_sock);
 	g_assert (IS_CONNECTION (conn));
 
-	conn->http_connection = NULL;
+	conn->http_request = NULL;
 
 	if ( ! success) {
                 log ("%d connect failed", conn->id);
@@ -750,7 +755,7 @@ proxy_do_connect(Socket *client_sock)
 	u_replace_string (&(conn->request->version), g_strdup("1.0")); 
 
 	/* Make Session callback
-	 * Note that the callback is allowed to modify headers and the HTTPRequest
+	 * Note that the callback is allowed to modify headers and the HTTPRequestLine
 	 * The callback is also allowed to cause the event loop to iterate;
 	 * any socket EOF events will be queued until the sockets are thawed
 	 */
@@ -789,7 +794,7 @@ proxy_do_connect(Socket *client_sock)
 		}
 #endif
 
-		conn->http_connection 
+		conn->http_request 
 			= http_connection_connect (
 				conn->request, 
 				conn->header_list_request, 
@@ -802,7 +807,7 @@ proxy_do_connect(Socket *client_sock)
 		/* this gets gobbled by http_connection_connect */
 		conn->header_list_request = NULL;
 
-		if ( NULL == conn->http_connection ) {
+		if ( NULL == conn->http_request ) {
 			http_error_log (client_sock, 400, "Failed to connect to remote host.");
 			socket_set_eof_fn (client_sock, NULL);
 			proxy_abort_connect (client_sock);
@@ -972,14 +977,15 @@ void proxy_get_request_eof(Socket *client_sock)
  */
 
 unsigned short
-proxy_listen (unsigned short port, gpointer user_data, const ProxyCallbackInfo * callbacks, const char *target_path)
+proxy_listen (const char *address, unsigned short port, gpointer user_data, const ProxyCallbackInfo * callbacks,
+	      const char *target_path)
 {
 	Socket *listen_socket = NULL;
 	ProxySession *session;
 
 	if ( 0 == port ) {
 		for (port = PORT_START; port < PORT_END; port++) {
-			listen_socket = socket_new("127.0.0.1", port);
+			listen_socket = socket_new (address, port);
 			if (listen_socket) {
 				/* success, bail */
 				break;
@@ -991,7 +997,7 @@ proxy_listen (unsigned short port, gpointer user_data, const ProxyCallbackInfo *
 			goto error;
 		}
 	} else {
-		listen_socket = socket_new("127.0.0.1", port);
+		listen_socket = socket_new(address, port);
 		if (NULL == listen_socket) {
 			log ("Couldn't listen on port %d", port);
 			port = 0;
@@ -1047,7 +1053,7 @@ proxy_new_connection(Socket *client_sock, gpointer user_data, const char *host,
 	session = (ProxySession *)user_data;
 	g_assert ( IS_SESSION (session) );
 
-	if (! eazel_check_connection(client_sock->fd)) {
+	if (config.check_uid && ! eazel_check_connection(client_sock->fd)) {
 		log("attempted connection from an invalid UID");
 		socket_set_eof_fn (client_sock, NULL);
 		socket_close (client_sock);
