@@ -1,4 +1,4 @@
-/* $Id: eazel-proxy-util.c,v 1.37 2000/10/30 21:08:41 mfleming Exp $
+/* $Id: eazel-proxy-util.c,v 1.40 2001/01/19 00:08:09 robey Exp $
  * 
  * eazel-proxy-util:
  * 
@@ -44,6 +44,7 @@
 #include <time.h>
 #include <gnome.h>
 #include <libgnomeui/libgnomeui.h> 
+#include <gconf/gconf.h>
 
 /* If authentication fails--for whatever reason--ignore subsequent requests for a few seconds
  * so we don't get redundent login boxes from the same operation
@@ -129,7 +130,8 @@ eazel_proxy_util_change_password (
 	EazelProxy_UserControl cntl, 
 	const char *login, 
 	const char *old_passwd,
-	const char *new_passwd
+	const char *new_passwd,
+        int *fail_code
 );
 
 
@@ -148,6 +150,8 @@ int main (int argc, char **argv)
 	CORBA_ORB orb;
 	poptContext popt_context;
 	int rc;
+	GError *gerror = NULL;
+	char * fake_argv[] = {"eazel-proxy-util", NULL};
 
 	CORBA_exception_init (&ev);
 
@@ -164,6 +168,12 @@ int main (int argc, char **argv)
 	gl_poa = (PortableServer_POA)CORBA_ORB_resolve_initial_references(orb, "RootPOA", &ev);
 	PortableServer_POAManager_activate(PortableServer_POA__get_the_POAManager(gl_poa, &ev), &ev);
 
+	/* init gconf, which is needed by ammonite */
+	if (!gconf_init (1, fake_argv, &gerror)) {
+		fprintf (stderr, "GConf init failed:\n  %s", gerror->message);
+		exit (-1);
+	}
+
 	if (! ammonite_init(gl_poa) ) {
 		fprintf (stderr, "Error during ammonite_init()\n");
 		exit (-1);
@@ -228,8 +238,6 @@ int main (int argc, char **argv)
 	
 	poptFreeContext (popt_context);
 
-	CORBA_Object_release (gl_user_control, &ev);
-
 	return 0;	
 }
 
@@ -265,6 +273,8 @@ try_init_gnome ()
 
 		is_gnome_inited = TRUE;
 
+
+
 		/* Disconnect from the session manager so we don't get 
 		 * annoying "SaveYourself" dialogs
 		 */
@@ -396,7 +406,7 @@ do_login_prompt (
 		exit (-1);
 	}
 
-	user = ammonite_do_prompt_login (NULL, target_path, login_path, &fail_code);
+	user = ammonite_do_prompt_login (NULL, target_path, login_path, TRUE, &fail_code);
 
 	if ( NULL != user ) {
 		printf ("Login succeeded for user '%s' on port %d.\n", 
@@ -956,7 +966,10 @@ do_translate (EazelProxy_UserControl cntl)
 
 			parsed = ammonite_url_parse (line);
 			if (parsed && gnome_inited) {
-				user_info = ammonite_do_prompt_login (parsed->user, NULL, NULL, NULL);
+				user_info = ammonite_do_prompt_login (
+						parsed->user, NULL, NULL,
+						parsed->user == NULL ? TRUE : FALSE,
+						NULL);
 				if (user_info) {
 					err = ammonite_http_url_for_eazel_url (line, &new_url);
 					/* I'm just not going to deal with this unlikely fail case */
@@ -994,7 +1007,8 @@ eazel_proxy_util_change_password (
 	EazelProxy_UserControl cntl, 
 	const char *login, 
 	const char *old_passwd,
-	const char *new_passwd
+	const char *new_passwd,
+        int *fail_code
 ) {
 	CORBA_Environment ev;
 	EazelProxy_AuthnCallback authn_callback;
@@ -1032,7 +1046,7 @@ eazel_proxy_util_change_password (
 	CORBA_free (authinfo);
 
 	if (CORBA_NO_EXCEPTION != ev._major) {
-		fprintf (stderr, "Exception during authenticate_user\n");
+		fprintf (stderr, "Exception during authenticate_user: %s\n", CORBA_exception_id (&ev));
 	} else {
 		while ( ! state.done && ! CORBA_Object_non_existent (cntl, &ev) ) {
 			g_main_iteration(TRUE);
@@ -1040,7 +1054,11 @@ eazel_proxy_util_change_password (
 
 		if (state.success) {
 			user = state.user;
-		}
+		} else {
+                        if (fail_code != NULL) {
+                                *fail_code = state.code;
+                        }
+                }
 	}
 
 	ammonite_auth_callback_wrapper_free (gl_poa, authn_callback);
@@ -1059,6 +1077,7 @@ do_change_password (EazelProxy_UserControl cntl)
 	char * new_passwd0 = NULL;
 	char * new_passwd1 = NULL;
 	char *prompt = NULL;
+        int fail_code = 0;
 	EazelProxy_User *user;
 
 	username = g_malloc (USERNAME_SIZE * sizeof (char));
@@ -1078,14 +1097,33 @@ do_change_password (EazelProxy_UserControl cntl)
 	}
 
 	user = eazel_proxy_util_change_password (cntl, username,  
-				orig_passwd, new_passwd0
-	       );
+                                                 orig_passwd, new_passwd0, &fail_code
+                                                 );
 
 	if ( NULL != user ) {
 		printf ("Change password succeeded.\n");
 		CORBA_free (user);
 	} else {
 		printf ("Change password FAILED.\n");
-	}
+                switch (fail_code) {
+                case EAZELPROXY_PASSWORD_CHANGE_BAD_ORIGINAL:
+                        printf ("Original password incorrect.\n");
+                        break;
+                case EAZELPROXY_PASSWORD_CHANGE_TOO_SHORT:
+                        printf ("Password must be at least six (6) characters long.\n");
+                        break;
+                case EAZELPROXY_PASSWORD_CHANGE_TOO_LONG:
+                        printf ("Whoa Nelly!!  Password must be less than 4000 characters long!\n");
+                        break;
+                case EAZELPROXY_PASSWORD_CHANGE_BAD_MATCH:
+                        printf ("New password entries didn't match.\n");
+                        break;
+                case EAZELPROXY_PASSWORD_CHANGE_TOO_BLAND:
+                        printf ("Password must contain letters plus at least one number or symbol.\n");
+                        break;
+                default:
+                        printf ("Unknown error %d\n", fail_code);
+                }
+        }
 }
 
